pecos.foreign\_objects.foreign\_object\_abc
===========================================

.. automodule:: pecos.foreign_objects.foreign_object_abc











   .. rubric:: Classes

   .. autosummary::

      ForeignObject
